pub mod django;
pub mod docker;
pub mod docker_compose;
pub mod postgres;

use std::{
    ffi::OsStr,
    fs::{File, OpenOptions},
    path::PathBuf,
    process::Command,
};

use anyhow::{Context, Result};

struct DockerCommand {
    command: Command,
}

impl DockerCommand {
    fn new<T>(program: T) -> Self
    where
        T: AsRef<OsStr>,
    {
        DockerCommand {
            command: Command::new(program),
        }
    }

    fn docker() -> Self {
        Self::new("docker")
    }

    fn docker_compose() -> Self {
        Self::new("docker").args("compose -f docker/local/docker-compose.yaml")
    }

    fn args(mut self, args: &str) -> Self {
        self.command.args(args.split_whitespace());
        self
    }

    fn stdout(mut self) -> Result<String> {
        Ok(String::from_utf8(self.command.output()?.stdout)?)
    }

    fn spawn_wait(mut self) -> Result<()> {
        self.command.spawn()?.wait()?;
        Ok(())
    }
}

fn safe_create_file(path: PathBuf) -> Result<File, std::io::Error> {
    OpenOptions::new().write(true).create_new(true).open(path)
}

fn create_file(path: PathBuf) -> Result<File, std::io::Error> {
    OpenOptions::new().write(true).create(true).open(path)
}
